@@ -17,7 +17,7 @@
 import os
 import sys
 from cl_utils import convertStrListDict, fillstr, getpathenv, runOsCommand,\
-                     pathJoin
+                     pathJoin, _toUNICODE
 from cl_vars_share import varsShare as glob_attr
 import re
 from cl_lang import lang
@@ -42,8 +42,8 @@ class var:
     value = ""
     # режим записи (атрибут mode)
     mode = "r"
-    # переменная для внутреннего использования (official)
-    official = False
+    # скрытая переменная
+    hide = False
     # был ли вызван метод заполнения
     isCallFill = False
     # объект в котором создан этот объект
@@ -179,14 +179,15 @@ class DataVars(object):
         """
         # Ищем переменную в модуле
         dataVar = False
+        dataVarWork = False
         e = False
-        for section, moduleVar, fillobj in self._importList:
-            try:
-                dataVar = getattr(moduleVar.Data, nameVar)
-            except AttributeError, e:
-                pass
-            if not dataVar is False:
-                break
+        for sectionWork, moduleVar, fillobj in self._importList:
+            if not hasattr(moduleVar.Data, nameVar):
+                continue
+            dataVarWork = getattr(moduleVar.Data, nameVar)
+            section = sectionWork
+            if dataVar is False:
+                dataVar = dataVarWork
         if dataVar == False:
             err1 = _("Not found variable %s")%nameVar
             err2 = ""
@@ -413,14 +414,19 @@ storage of variables templates")%location)
         if not header:
             header = self.__getSection(vname)
         # Удаляем переменную
-        retDelVar = config.delVar(header, vname)
-        retDelArea = True
-        if not config.getAreaVars(header):
-            retDelArea = config.delArea(header)
-        if retDelArea and retDelVar:
-            return True
-        else:
+        allVars = config.getAreaVars(header)
+        if allVars is False:
             return False
+        if vname in allVars.keys():
+            retDelVar = config.delVar(header, vname)
+            retDelArea = True
+            if not config.getAreaVars(header):
+                retDelArea = config.delArea(header)
+            if retDelArea and retDelVar:
+                return True
+            else:
+                return False
+        return True
 
     def Write(self,vname,val=None,force=False,location='default',header=False):
         '''Установить и записать значение переменной в ini файл
@@ -594,7 +600,7 @@ storage of variables templates")%location)
                 break
         return foundVar
 
-    def getVars(self, varsFilter=None, varsNames=[]):
+    def getVars(self, varsFilter=None, varsNames=[], verbose=1):
         """Словарь переменных для печати"""
         # проверка фильтра
         reFilter = False
@@ -606,52 +612,80 @@ storage of variables templates")%location)
                                          %str(varsFilter))
                 cl_overriding.exit(1)
         ret = {}
+        dictServicesVars = {}
         for section, moduleVar, fillobj in self._importList:
             dataVar = moduleVar.Data
             dictVars = dir(dataVar)
             for nameVar in dictVars:
-                if not "__" in nameVar and not\
-                    (getattr(dataVar,nameVar).has_key("official") and\
-                     getattr(dataVar,nameVar)['official']):
+                if not "__" in nameVar and (not\
+                    (getattr(dataVar,nameVar).has_key("hide") and\
+                     getattr(dataVar,nameVar)['hide']) or verbose>1):
                     if varsNames and not nameVar in varsNames:
                         continue
                     if reFilter and not reFilter.search(nameVar):
                         continue
                     self.Get(nameVar)
-                    ret[nameVar] = getattr(self, nameVar)
-        return ret
+                    variable = getattr(self, nameVar)
+                    service = variable.service.lower()
+                    ret[nameVar] = variable
+                    if not service in dictServicesVars:
+                        dictServicesVars[service] = {}
+                    dictServicesVars[service][nameVar] = variable
+        return ret, dictServicesVars
 
-    def printVars(self, varsFilter=None, varsNames=[], outFormat="default"):
+    def printVars(self, varsFilter=None, varsNames=[], outFormat="default",
+                  verbose=1):
         """распечатать список переменных с значениями"""
-        var=None
-        var=self.getVars(varsFilter, varsNames)
-        if outFormat == "default":
+        def getLenElements(varsDict):
             mlen_name=0;
             mlen_type=0;
             mlen_mode=0;
-            for i,j in var.items():
+            for i,j in varsDict.items():
                 if len(i)>mlen_name:
                     mlen_name=len(i)
-                if not '[' in var[i].mode:
-                    mode="[%s]"%(var[i].mode.lower())
-                var[i].mode=mode
+                if not '[' in varsDict[i].mode:
+                    mode="[%s]"%(varsDict[i].mode.lower())
+                varsDict[i].mode=mode
                 if len(mode)>mlen_mode:
                     mlen_mode=len(mode)
-            plist=var.keys()
+            return mlen_name, mlen_type, mlen_mode
+
+        def printVarsTable(varsDict, title, lenList=()):
+            """print variables table"""
+            if lenList:
+                mlen_name, mlen_type, mlen_mode = lenList;
+            else:
+                mlen_name, mlen_type, mlen_mode = getLenElements(varsDict)
+            plist=varsDict.keys()
             plist.sort()
             br = fillstr("-",mlen_name) + " " +\
                 fillstr("-",mlen_mode) + " " +  fillstr("-",10)
-            cl_overriding.printSUCCESS(_("The list of variables:"))
-            cl_overriding.printSUCCESS(_("Variable name").center(mlen_name) +\
+            cl_overriding.printSUCCESS(title)
+            cl_overriding.printSUCCESS(br)
+            cl_overriding.printSUCCESS(\
+            _toUNICODE(_("Variable name")).center(mlen_name).encode('UTF-8') +\
                                        " " + _("Mode") + " " +_("Value"))
             cl_overriding.printSUCCESS(br)
             for i in plist:
                 if i.endswith("_pw"):
                     p_val = "***"
                 else:
-                    p_val=var[i].value
-                columnWrite(i, mlen_name, var[i].mode.lower(), mlen_mode, p_val)
-            cl_overriding.printSUCCESS(br)
+                    p_val=varsDict[i].value
+                columnWrite(i, mlen_name, varsDict[i].mode.lower(),
+                            mlen_mode, p_val)
+        var, dictPkgVars = self.getVars(varsFilter, varsNames, verbose=verbose)
+        if outFormat == "default":
+            lenList = getLenElements(var)
+            libService = 'main'
+            if libService in dictPkgVars:
+                var = dictPkgVars.pop(libService)
+                printVarsTable(var, _("The list of %s variables:")%'library',
+                               lenList=lenList)
+            for service in dictPkgVars.keys():
+                var = dictPkgVars[service]
+                cl_overriding.printSUCCESS("")
+                printVarsTable(var, _("The list of %s variables:")%service,
+                               lenList=lenList)
         elif outFormat == "xml":
             xmlObj = _varsXML()
             varNames = sorted(var.keys())
