@@ -390,7 +390,7 @@ class varsShare:
         config      config file name
         name        param name
         """
-        reMatch = re.compile("^%s\s*=\s*\"?(.*?)\"?$"%name, re.I)
+        reMatch = re.compile("^%s\s*=\s*\"?(.*?)(\"\s*)?$"%name, re.I)
         try:
             if path.exists(config):
                 for line in open(config,"r").readlines():
@@ -456,8 +456,9 @@ class varsShare:
         pkgInfoDir = path.join(systemroot,'var/db/pkg/app-misc/')
         if not os.access(pkgInfoDir,os.R_OK):
             return None
-        metaPkgs = filter(lambda x:"calculate-meta" in x,
-                          os.listdir(pkgInfoDir))
+        metaPkgs = sorted(filter(lambda x:"calculate-meta" in x or \
+                                 "%s-meta"%shortname.lower() in x,
+                          os.listdir(pkgInfoDir)))
         if metaPkgs:
             reFindVer = re.compile("(?<=\-)\d+\.?\d*\.?\d*")
             findVer = reFindVer.search(metaPkgs[0])
